import { IFlag, IArg } from 'cli-flags';
export declare type UserConfig = {
    skipAnalytics?: boolean | undefined | null;
    install?: string | undefined | null;
};
export declare type Topic = {
    name: string;
    description?: string;
    hidden?: boolean;
};
export declare type S3 = {
    host?: string;
};
export declare type CLI = {
    bin?: string;
    dirname?: string;
    defaultCommand?: string;
    commands?: string;
    s3?: S3;
    hooks?: {
        [name: string]: string | string[];
    };
    aliases?: {
        [from: string]: string | string[];
    };
    userPlugins: boolean;
    plugins?: string[];
    legacyConverter?: string;
    topics?: {
        [name: string]: Topic;
    };
    npmRegistry?: string;
};
export declare type PJSON = {
    name: string;
    version: string;
    dependencies: {
        [name: string]: string;
    };
    'cli-engine': CLI;
};
export declare type Config = {
    name: string;
    dirname: string;
    initPath: string;
    commandsDir: string;
    bin: string;
    s3: S3;
    root: string;
    home: string;
    pjson: PJSON;
    updateDisabled: string;
    defaultCommand: string;
    channel: string;
    version: string;
    debug: number;
    reexecBin?: string;
    dataDir: string;
    cacheDir: string;
    configDir: string;
    arch: string;
    platform: string;
    windows: boolean;
    _version: '1';
    skipAnalytics: boolean;
    install: string;
    userAgent: string;
    shell: string;
    hooks: {
        [name: string]: string[];
    };
    aliases: {
        [from: string]: string[];
    };
    userConfig: UserConfig;
    argv: string[];
    mock: boolean;
    userPlugins: boolean;
    corePlugins: string[];
    topics: {
        [name: string]: Topic;
    };
    legacyConverter?: string;
    errlog: string;
    npmRegistry: string;
    __cache: any;
};
export declare type ConfigOptions = Partial<Config>;
export declare type AlphabetUppercase = 'A' | 'B' | 'C' | 'D' | 'E' | 'F' | 'G' | 'H' | 'I' | 'J' | 'K' | 'L' | 'M' | 'N' | 'O' | 'P' | 'Q' | 'R' | 'S' | 'T' | 'U' | 'V' | 'X' | 'Y' | 'Z';
export declare type AlphabetLowercase = 'a' | 'b' | 'c' | 'd' | 'e' | 'f' | 'g' | 'h' | 'i' | 'j' | 'k' | 'l' | 'm' | 'n' | 'o' | 'p' | 'q' | 'r' | 's' | 't' | 'u' | 'v' | 'x' | 'y' | 'z';
export declare type CompletionContext = {
    args?: {
        [name: string]: string;
    };
    flags?: {
        [name: string]: string;
    };
    argv?: string[];
    config: Config;
};
export declare type Completion = {
    skipCache?: boolean;
    cacheDuration?: number;
    cacheKey?: (completion: CompletionContext) => Promise<string>;
    options: (completion: CompletionContext) => Promise<string[]>;
};
export declare type Plugin = {
    name: string;
    version: string;
    type: string;
    root: string;
};
export interface ICommand {
    topic?: string;
    command?: string;
    description?: string;
    hidden: boolean;
    usage?: string;
    help?: string;
    _version: string;
    id: string;
    buildHelp: (config: Config) => string;
    buildHelpLine: (config: Config) => [string, string | undefined];
    args?: IArg[];
    flags?: {
        [name: string]: IFlag<any>;
    };
    run: (options: Config) => Promise<any>;
    plugin?: Plugin;
}
export declare function buildConfig(existing?: ConfigOptions): Config;
export declare const defaultConfig: Config;
